@@ -1,4 +1,5 @@
 import logging
+from typing import Any, Dict
 
 from graphein.utils.utils import import_message
 
@@ -16,12 +17,15 @@ except ImportError:
     log.warning(message)
 
 
-def add_sequence_to_nodes(n, d):
+def add_sequence_to_nodes(n: str, d: Dict[str, Any]):
     """
-    Maps UniProt ACC to UniProt ID. Retrieves sequence from UniProt and adds it to the node
+    Maps UniProt ACC to UniProt ID. Retrieves sequence from UniProt and adds
+    it to the node
 
-    :param n: Graph node.
+    :param n: Graph node. Unused (retained for a consistent function signature).
+    :type n: str
     :param d: Graph attribute dictionary.
+    :type d: Dict[str, Any]
     """
 
     h = HGNC(verbose=False)
@@ -35,4 +39,4 @@ def add_sequence_to_nodes(n, d):
     # Todo mapping with bioservices to support other protein IDs?
 
     for id in d["uniprot_ids"]:
-        d[f"sequence_{id}"] = u.get_fasta_sequence(id)
+        d[f"sequence_{id}"] = u.search(id, columns="sequence").split("\n")[1]
