@@ -41,6 +41,7 @@ class InMemoryProteinGraphDataset(InMemoryDataset):
         self,
         root: str,
         name: str,
+        pdb_paths: Optional[List[str]] = None,
         pdb_codes: Optional[List[str]] = None,
         uniprot_ids: Optional[List[str]] = None,
         graph_label_map: Optional[Dict[str, torch.Tensor]] = None,
@@ -72,6 +73,8 @@ class InMemoryProteinGraphDataset(InMemoryDataset):
         :type root: str
         :param name: Name of the dataset. Will be saved to ``data_$name.pt``.
         :type name: str
+        :param pdb_paths: List of full path of pdb files to load. Defaults to ``None``.
+        :type pdb_paths: Optional[List[str]], optional
         :param pdb_codes: List of PDB codes to download and parse from the PDB.
             Defaults to None.
         :type pdb_codes: Optional[List[str]], optional
@@ -135,6 +138,23 @@ class InMemoryProteinGraphDataset(InMemoryDataset):
             else None
         )
 
+        self.pdb_paths = pdb_paths
+        if self.pdb_paths is None:
+            if self.pdb_codes and self.uniprot_ids:
+                self.structures = self.pdb_codes + self.uniprot_ids
+            elif self.pdb_codes:
+                self.structures = pdb_codes
+            elif self.uniprot_ids:
+                self.structures = uniprot_ids
+        # Use local saved pdb_files instead of download or move them to self.root/raw dir
+        else:
+            if isinstance(self.pdb_paths, list):
+                self.structures = [
+                    os.path.splitext(os.path.split(pdb_path)[-1])[0]
+                    for pdb_path in self.pdb_paths
+                ]
+                self.pdb_path, _ = os.path.split(self.pdb_paths[0])
+
         if self.pdb_codes and self.uniprot_ids:
             self.structures = self.pdb_codes + self.uniprot_ids
         elif self.pdb_codes:
@@ -157,6 +177,7 @@ class InMemoryProteinGraphDataset(InMemoryDataset):
         self.graph_transformation_funcs = graph_transformation_funcs
         self.pdb_transform = pdb_transform
         self.num_cores = num_cores
+        self.af_version = af_version
         super().__init__(
             root,
             transform=transform,
@@ -176,6 +197,13 @@ class InMemoryProteinGraphDataset(InMemoryDataset):
         """Name of the processed file."""
         return [f"data_{self.name}.pt"]
 
+    @property
+    def raw_dir(self) -> str:
+        if self.pdb_paths is not None:
+            return self.pdb_path  # replace raw dir with user local pdb_path
+        else:
+            return os.path.join(self.root, "raw")
+
     def download(self):
         """Download the PDB files from RCSB or Alphafold."""
         self.config.pdb_dir = Path(self.raw_dir)
@@ -298,7 +326,8 @@ class InMemoryProteinGraphDataset(InMemoryDataset):
 class ProteinGraphDataset(Dataset):
     def __init__(
         self,
-        root,
+        root: str,
+        pdb_paths: Optional[List[str]] = None,
         pdb_codes: Optional[List[str]] = None,
         uniprot_ids: Optional[List[str]] = None,
         # graph_label_map: Optional[Dict[str, int]] = None,
@@ -327,6 +356,8 @@ class ProteinGraphDataset(Dataset):
 
         :param root: Root directory where the dataset should be saved.
         :type root: str
+        :param pdb_paths: List of full path of pdb files to load. Defaults to ``None``.
+        :type pdb_paths: Optional[List[str]], optional
         :param pdb_codes: List of PDB codes to download and parse from the PDB.
             Defaults to ``None``.
         :type pdb_codes: Optional[List[str]], optional
@@ -388,14 +419,22 @@ class ProteinGraphDataset(Dataset):
             if uniprot_ids is not None
             else None
         )
-
-        if self.pdb_codes and self.uniprot_ids:
-            self.structures = self.pdb_codes + self.uniprot_ids
-        elif self.pdb_codes:
-            self.structures = pdb_codes
-        elif self.uniprot_ids:
-            self.structures = uniprot_ids
-        self.af_version = af_version
+        self.pdb_paths = pdb_paths
+        if self.pdb_paths is None:
+            if self.pdb_codes and self.uniprot_ids:
+                self.structures = self.pdb_codes + self.uniprot_ids
+            elif self.pdb_codes:
+                self.structures = pdb_codes
+            elif self.uniprot_ids:
+                self.structures = uniprot_ids
+        # Use local saved pdb_files instead of download or move them to self.root/raw dir
+        else:
+            if isinstance(self.pdb_paths, list):
+                self.structures = [
+                    os.path.splitext(os.path.split(pdb_path)[-1])[0]
+                    for pdb_path in self.pdb_paths
+                ]
+                self.pdb_path, _ = os.path.split(self.pdb_paths[0])
 
         # Labels & Chains
 
@@ -424,6 +463,7 @@ class ProteinGraphDataset(Dataset):
         self.num_cores = num_cores
         self.pdb_transform = pdb_transform
         self.graph_transformation_funcs = graph_transformation_funcs
+        self.af_version = af_version
         super().__init__(
             root,
             transform=transform,
@@ -450,6 +490,13 @@ class ProteinGraphDataset(Dataset):
         else:
             return [f"{pdb}.pt" for pdb in self.structures]
 
+    @property
+    def raw_dir(self) -> str:
+        if self.pdb_paths is not None:
+            return self.pdb_path  # replace raw dir with user local pdb_path
+        else:
+            return os.path.join(self.root, "raw")
+
     def validate_input(self):
         if self.graph_label_map is not None:
             assert len(self.structures) == len(
@@ -554,6 +601,7 @@ class ProteinGraphDataset(Dataset):
 
             # Create graph objects
             file_names = [f"{self.raw_dir}/{pdb}.pdb" for pdb in pdbs]
+
             graphs = construct_graphs_mp(
                 pdb_path_it=file_names,
                 config=self.config,
