@@ -237,6 +237,10 @@ def add_disulfide_interactions(
     disulfide_df = filter_dataframe(
         disulfide_df, "atom_name", DISULFIDE_ATOMS, True
     )
+    # Ensure only residues in the graph are kept
+    disulfide_df = filter_dataframe(
+        disulfide_df, "node_id", list(G.nodes), True
+    )
     distmat = compute_distmat(disulfide_df)
     interacting_atoms = get_interacting_atoms(2.2, distmat)
     add_interacting_resis(G, interacting_atoms, disulfide_df, ["disulfide"])
@@ -1194,10 +1198,7 @@ def node_coords(G: nx.Graph, n: str) -> Tuple[float, float, float]:
     :return: Tuple of coordinates ``(x, y, z)``
     :rtype: Tuple[float, float, float]
     """
-    x = G.nodes[n]["x_coord"]
-    y = G.nodes[n]["y_coord"]
-    z = G.nodes[n]["z_coord"]
-
+    x, y, z = tuple(G.nodes[n]["coords"])
     return x, y, z
 
 
