@@ -32,15 +32,15 @@ def extract_subgraph_from_node_list(
     :type g: nx.Graph
     :param node_list: The list of nodes to extract.
     :type node_list: List[str]
-    :param filter_dataframe: Whether to filter the pdb_df dataframe of the graph. Defaults to True.
+    :param filter_dataframe: Whether to filter the ``pdb_df`` dataframe of the graph. Defaults to ``True``.
     :type filter_dataframe: bool
-    :param update_coords: Whether to update the coordinates of the graph. Defaults to True.
+    :param update_coords: Whether to update the coordinates of the graph. Defaults to ``True``.
     :type update_coords: bool
-    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to False.
+    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to ``False``.
     :type recompute_distmat: bool
-    :param inverse: Whether to inverse the selection. Defaults to False.
+    :param inverse: Whether to inverse the selection. Defaults to ``False``.
     :type inverse: bool
-    :return: The subgraph or node list if return_node_list is True.
+    :return: The subgraph or node list if ``return_node_list=True``.
     :rtype: Union[nx.Graph, List[str]]
     """
     if node_list:
@@ -54,7 +54,7 @@ def extract_subgraph_from_node_list(
 
         log.debug(f"Creating subgraph from nodes: {node_list}.")
         # Create a subgraph from the node list.
-        g = g.subgraph(node_list)
+        g = g.subgraph(node_list).copy()
         # Filter the PDB DF accordingly
         if filter_dataframe:
             g.graph["pdb_df"] = g.graph["pdb_df"].loc[
@@ -67,7 +67,10 @@ def extract_subgraph_from_node_list(
         if recompute_distmat:
             if not filter_dataframe:
                 log.warning("Recomputing distmat without filtering dataframe.")
-            g.graph["distmat"] = compute_distmat(g.graph["pdb_df"])
+            g.graph["dist_mat"] = compute_distmat(g.graph["pdb_df"])
+        # Reset numbering for edge funcs
+        g.graph["pdb_df"] = g.graph["pdb_df"].reset_index(drop=True)
+
     if return_node_list:
         return node_list
 
@@ -92,15 +95,15 @@ def extract_subgraph_from_point(
     :type centre_point: Tuple[float, float, float]
     :param radius: The radius of the subgraph.
     :type radius: float
-    :param filter_dataframe: Whether to filter the pdb_df dataframe of the graph. Defaults to True.
+    :param filter_dataframe: Whether to filter the pdb_df dataframe of the graph. Defaults to ``True``.
     :type filter_dataframe: bool
-    :param update_coords: Whether to update the coordinates of the graph. Defaults to True.
+    :param update_coords: Whether to update the coordinates of the graph. Defaults to ``True``.
     :type update_coords: bool
-    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to False.
+    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to ``False``.
     :type recompute_distmat: bool
-    :param inverse: Whether to inverse the selection. Defaults to False.
+    :param inverse: Whether to inverse the selection. Defaults to ``False``.
     :type inverse: bool
-    :return: The subgraph or node list if return_node_list is True.
+    :return: The subgraph or node list if ``return_node_list=True``.
     :rtype: Union[nx.Graph, List[str]]
     """
     node_list: List = []
@@ -142,15 +145,15 @@ def extract_subgraph_from_atom_types(
     :type g: nx.Graph
     :param atom_types: The list of atom types to extract.
     :type atom_types: List[str]
-    :param filter_dataframe: Whether to filter the pdb_df dataframe of the graph. Defaults to True.
+    :param filter_dataframe: Whether to filter the ``pdb_df`` dataframe of the graph. Defaults to ``True``.
     :type filter_dataframe: bool
-    :param update_coords: Whether to update the coordinates of the graph. Defaults to True.
+    :param update_coords: Whether to update the coordinates of the graph. Defaults to ``True``.
     :type update_coords: bool
-    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to False.
+    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to ``False``.
     :type recompute_distmat: bool
-    :param inverse: Whether to inverse the selection. Defaults to False.
+    :param inverse: Whether to inverse the selection. Defaults to ``False``.
     :type inverse: bool
-    :return: The subgraph or node list if return_node_list is True.
+    :return: The subgraph or node list if ``return_node_list=True``.
     :rtype: Union[nx.Graph, List[str]]
     """
     node_list: List = [
@@ -184,17 +187,17 @@ def extract_subgraph_from_residue_types(
 
     :param g: The graph to extract the subgraph from.
     :type g: nx.Graph
-    :param residue_types: List of allowable residue types (3 letter residue names).
+    :param residue_types: List of allowable residue types (3 letter residue names). E.g. ``["SER", "GLY", "ALA"]``
     :type residue_types: List[str]
-    :param filter_dataframe: Whether to filer the pdb_df of the graph, defaults to True
+    :param filter_dataframe: Whether to filer the pdb_df of the graph, defaults to ``True``
     :type filter_dataframe: bool, optional
-    :param update_coords: Whether to update the coordinates of the graph. Defaults to True.
+    :param update_coords: Whether to update the coordinates of the graph. Defaults to ``True``.
     :type update_coords: bool
-    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to False.
+    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to ``False``.
     :type recompute_distmat: bool
-    :param inverse: Whether to inverse the selection. Defaults to False.
+    :param inverse: Whether to inverse the selection. Defaults to ``False``.
     :type inverse: bool
-    :return: The subgraph or node list if return_node_list is True.
+    :return: The subgraph or node list if ``return_node_list=True``.
     :rtype: Union[nx.Graph, List[str]]
     """
     node_list: List = [
@@ -228,17 +231,17 @@ def extract_subgraph_from_chains(
 
     :param g: The graph to extract the subgraph from.
     :type g: nx.Graph
-    :param chain: The chain(s) to extract.
+    :param chain: The chain(s) to extract. E.g. ``["A", "C", "E"]`` or ``["A"]``.
     :type chain: List[str]
-    :param filter_dataframe: Whether to filter the pdb_df dataframe of the graph. Defaults to True.
+    :param filter_dataframe: Whether to filter the ``pdb_df`` dataframe of the graph. Defaults to ``True``.
     :type filter_dataframe: bool
-    :param update_coords: Whether to update the coordinates of the graph. Defaults to True.
+    :param update_coords: Whether to update the coordinates of the graph. Defaults to ``True``.
     :type update_coords: bool
-    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to False.
+    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to ``False``.
     :type recompute_distmat: bool
-    :param inverse: Whether to inverse the selection. Defaults to False.
+    :param inverse: Whether to inverse the selection. Defaults to ``False``.
     :type inverse: bool
-    :return: The subgraph or node list if return_node_list is True.
+    :return: The subgraph or node list if ``return_node_list=True``.
     :rtype: Union[nx.Graph, List[str]]
     """
     node_list: List = [
@@ -267,21 +270,21 @@ def extract_subgraph_by_sequence_position(
     inverse: bool = False,
     return_node_list: bool = False,
 ) -> Union[nx.Graph, List[str]]:
-    """Extracts a subgraph from a graph based on a chain.
+    """Extracts a subgraph from a graph based on position in the sequence
 
     :param g: The graph to extract the subgraph from.
     :type g: nx.Graph
-    :param chain: The sequence positions to extract.
+    :param chain: The sequence positions to extract. E.g. ``[1, 2, 3]`` or ``[1]``.
     :type chain: List[int]
-    :param filter_dataframe: Whether to filter the pdb_df dataframe of the graph. Defaults to True.
+    :param filter_dataframe: Whether to filter the ``pdb_df`` dataframe of the graph. Defaults to ``True``.
     :type filter_dataframe: bool
-    :param update_coords: Whether to update the coordinates of the graph. Defaults to True.
+    :param update_coords: Whether to update the coordinates of the graph. Defaults to ``True``.
     :type update_coords: bool
-    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to False.
+    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to ``False``.
     :type recompute_distmat: bool
-    :param inverse: Whether to inverse the selection. Defaults to False.
+    :param inverse: Whether to inverse the selection. Defaults to ``False``.
     :type inverse: bool
-    :return: The subgraph or node list if return_node_list is True.
+    :return: The subgraph or node list if ``return_node_list=True``.
     :rtype: Union[nx.Graph, List[str]]
     """
     node_list: List = [
@@ -318,19 +321,19 @@ def extract_subgraph_by_bond_type(
 
     :param g: The graph to extract the subgraph from.
     :type g: nx.Graph
-    :param bond_types: List of allowable bond types.
+    :param bond_types: List of allowable bond types. E.g. ``["hydrogen_bond", "k_nn_3"]``
     :type bond_types: List[str]
-    :param filter_dataframe: Whether to filter the pdb_df of the graph, defaults to True
+    :param filter_dataframe: Whether to filter the ``pdb_df`` of the graph, defaults to ``True``.
     :type filter_dataframe: bool, optional
-    :param update_coords: Whether to update the coordinates of the graph. Defaults to True.
+    :param update_coords: Whether to update the coordinates of the graph. Defaults to ``True``.
     :type update_coords: bool
-    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to False.
+    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to ``False``.
     :type recompute_distmat: bool
-    :param inverse: Whether to inverse the selection, defaults to False
+    :param inverse: Whether to inverse the selection, defaults to ``False``.
     :type inverse: bool, optional
-    :param return_node_list: Whether to return the node list, defaults to False
+    :param return_node_list: Whether to return the node list, defaults to ``False``.
     :type return_node_list: bool, optional
-    :return: The subgraph or node list if return_node_list is True.
+    :return: The subgraph or node list if ``return_node_list=True``.
     :rtype: Union[nx.Graph, List[str]]
     """
 
@@ -378,19 +381,19 @@ def extract_subgraph_from_secondary_structure(
 
     :param g: The graph to extract the subgraph from.
     :type g: nx.Graph
-    :param ss_elements: List of secondary structure elements to extract.
+    :param ss_elements: List of secondary structure elements to extract. E.g. ``["H", "E"]``
     :type ss_elements: List[str]
-    :param inverse: Whether to inverse the selection. Defaults to False.
+    :param inverse: Whether to inverse the selection. Defaults to ``False``.
     :type inverse: bool
-    :param filter_dataframe: Whether to filter the pdb_df of the graph, defaults to True
+    :param filter_dataframe: Whether to filter the ``pdb_df`` of the graph, defaults to ``True``.
     :type filter_dataframe: bool, optional
-    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to False.
+    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to ``False``.
     :type recompute_distmat: bool
-    :param update_coords: Whether to update the coordinates of the graph. Defaults to True.
+    :param update_coords: Whether to update the coordinates of the graph. Defaults to ``True``.
     :type update_coords: bool
-    :param return_node_list: Whether to return the node list. Defaults to False.
-    :raises ProteinGraphConfigurationError: If the graph does not contain ss features on the nodes (`d['ss'] not in d.keys() for _, d in g.nodes(data=True)`).
-    :return: The subgraph or node list if return_node_list is True.
+    :param return_node_list: Whether to return the node list. Defaults to ``False``.
+    :raises ProteinGraphConfigurationError: If the graph does not contain ss features on the nodes (``d['ss'] not in d.keys() for _, d in g.nodes(data=True)``).
+    :return: The subgraph or node list if ``return_node_list=True``.
     :rtype: Union[nx.Graph, List[str]]
     """
 
@@ -433,20 +436,20 @@ def extract_surface_subgraph(
 
     :param g: The graph to extract the subgraph from.
     :type g: nx.Graph
-    :param rsa_threshold: The threshold to use for the RSA. Defaults to 0.2 (20%)
+    :param rsa_threshold: The threshold to use for the RSA. Defaults to ``0.2`` (20%).
     :type rsa_threshold: float
-    :param filter_dataframe: Whether to filter the pdb_df of the graph, defaults to True
+    :param filter_dataframe: Whether to filter the ``pdb_df`` of the graph, defaults to ``True``.
     :type filter_dataframe: bool, optional
-    :param update_coords: Whether to update the coordinates of the graph. Defaults to True.
+    :param update_coords: Whether to update the coordinates of the graph. Defaults to ``True``.
     :type update_coords: bool
-    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to False.
+    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to ``False``.
     :type recompute_distmat: bool
-    :param inverse: Whether to inverse the selection, defaults to False
+    :param inverse: Whether to inverse the selection, defaults to ``False``.
     :type inverse: bool, optional
-    :param return_node_list: Whether to return the node list. Defaults to False.
+    :param return_node_list: Whether to return the node list. Defaults to ``False``.
     :type return_node_list: bool
-    :raises ProteinGraphConfigurationError: If the graph does not contain RSA features on the nodes (`d['rsa'] not in d.keys() for _, d in g.nodes(data=True)`).
-    :return: The subgraph or node list if return_node_list is True.
+    :raises ProteinGraphConfigurationError: If the graph does not contain RSA features on the nodes (``d['rsa'] not in d.keys() for _, d in g.nodes(data=True)``).
+    :return: The subgraph or node list if ``return_node_list=True``.
     :rtype: Union[nx.Graph, List[str]]
     """
     node_list: List[str] = []
@@ -488,23 +491,23 @@ def extract_k_hop_subgraph(
 
     :param g: The graph to extract the subgraph from.
     :type g: nx.Graph
-    :param central_node: The central node to extract the subgraph from.
+    :param central_node: The central node to extract the subgraph from. E.g. ``"A:SER:12"``.
     :type central_node: str
     :param k: The number of hops to extract.
     :type k: int
     :param k_only: Whether to only extract the exact k-hop subgraph (e.g. include 2-hop neighbours in 5-hop graph). Defaults to False.
     :type k_only: bool
-    :param filter_dataframe: Whether to filter the pdb_df of the graph, defaults to True
+    :param filter_dataframe: Whether to filter the ``pdb_df`` of the graph, defaults to ``True``.
     :type filter_dataframe: bool, optional
-    :param update_coords: Whether to update the coordinates of the graph. Defaults to True.
+    :param update_coords: Whether to update the coordinates of the graph. Defaults to ``True``.
     :type update_coords: bool
-    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to False.
+    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to ``False``.
     :type recompute_distmat: bool
-    :param inverse: Whether to inverse the selection, defaults to False
+    :param inverse: Whether to inverse the selection, defaults to ``False``.
     :type inverse: bool, optional
-    :param return_node_list: Whether to return the node list. Defaults to False.
+    :param return_node_list: Whether to return the node list. Defaults to ``False``.
     :type return_node_list: bool
-    :return: The subgraph or node list if return_node_list is True.
+    :return: The subgraph or node list if ``return_node_list=True``.
     :rtype: Union[nx.Graph, List[str]]
     """
     neighbours: Dict[int, Union[List[str], set]] = {0: [central_node]}
@@ -535,6 +538,86 @@ def extract_k_hop_subgraph(
     )
 
 
+def extract_interface_subgraph(
+    g: nx.Graph,
+    interface_list: Optional[List[str]] = None,
+    chain_list: Optional[List[str]] = None,
+    filter_dataframe: bool = True,
+    update_coords: bool = True,
+    recompute_distmat: bool = False,
+    inverse: bool = False,
+    return_node_list: bool = False,
+) -> Union[nx.Graph, List[str]]:
+    """Extracts a subgraph from a graph of a complexed structure (multiple chains).
+
+    If there is an edge between two nodes that are part of different chains it is included in the selection.
+    NB - if you want to be precise about the interfacial region, you should compute this on the basis of solvent
+    accessibility and make the selection with :method:`extract_subgraph_from_node_list`.
+
+    :param g: The graph to extract the subgraph from.
+    :type g: nx.Graph
+    :param interface_list: A list of interface names to extract e.g. ``["AB", "CD"]``. Default is ``None``.
+    :type interface_list: Optional[List[str]]
+    :param chain_list: A list of chain names to extract e.g. ``["A", "B"]``. Default is ``None``.
+    :type chain_list: Optional[List[str]]
+    :param filter_dataframe: Whether to filter the ``pdb_df`` dataframe of the graph. Defaults to ``True``.
+    :type filter_dataframe: bool
+    :param update_coords: Whether to update the coordinates of the graph. Defaults to ``True``.
+    :type update_coords: bool
+    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to ``False``.
+    :type recompute_distmat: bool
+    :param inverse: Whether to inverse the selection. Defaults to ``False``.
+    :type inverse: bool
+    :return: The subgraph or node list if ``return_node_list=True``.
+    :rtype: Union[nx.Graph, List[str]]
+    """
+    node_list: List[str] = []
+    # Iterate over edges
+    for u, v in g.edges():
+        u_chain = g.nodes[u]["chain_id"]
+        v_chain = g.nodes[v]["chain_id"]
+
+        # If a list of chain selections are given, check if the edge is between chains in the list
+        # Save nodes if the chains are not the same
+        if (
+            chain_list is not None
+            and u_chain in chain_list
+            and v_chain in chain_list
+            and u_chain != v_chain
+        ):
+            node_list.extend((u, v))
+
+        # If a list of valid interfaces is provided, check the nodes are in the valid interfaces
+        if interface_list is not None:
+            case_1 = u_chain + v_chain
+            case_2 = v_chain + u_chain
+            if case_1 in interface_list or case_2 in interface_list:
+                node_list.extend((u, v))
+
+            # In the absence of selection params
+        # Save nodes if the chains are not the same
+        if (
+            chain_list is None
+            and interface_list is None
+            and u_chain != v_chain
+        ):
+            node_list.extend((u, v))
+
+    node_list = list(set(node_list))
+
+    log.debug(f"Found {len(node_list)} nodes in the interface subgraph.")
+
+    return extract_subgraph_from_node_list(
+        g,
+        node_list,
+        filter_dataframe=filter_dataframe,
+        inverse=inverse,
+        return_node_list=return_node_list,
+        recompute_distmat=recompute_distmat,
+        update_coords=update_coords,
+    )
+
+
 def extract_subgraph(
     g: nx.Graph,
     node_list: Optional[List[str]] = None,
@@ -562,40 +645,40 @@ def extract_subgraph(
 
     :param g: The graph to extract the subgraph from.
     :type g: nx.Graph
-    :param node_list: List of nodes to extract specified by their node_id. Defaults to None.
+    :param node_list: List of nodes to extract specified by their ``node_id``. Defaults to ``None``.
     :type node_list: List[str], optional
-    :param sequence_positions: The sequence positions to extract. Defaults to None.
+    :param sequence_positions: The sequence positions to extract. Defaults to ``None``.
     :type sequence_positions: List[int], optional
-    :param chains: The chain(s) to extract. Defaults to None.
+    :param chains: The chain(s) to extract. Defaults to ``None``.
     :type chains: List[str], optional
-    :param residue_types: List of allowable residue types (3 letter residue names). Defaults to None.
+    :param residue_types: List of allowable residue types (3 letter residue names). Defaults to ``None``.
     :type residue_types: List[str], optional
-    :param atom_types: List of allowable atom types. Defaults to None.
+    :param atom_types: List of allowable atom types. Defaults to ``None``.
     :type atom_types: List[str], optional
-    :param centre_point: The centre point to extract the subgraph from. Defaults to None.
+    :param centre_point: The centre point to extract the subgraph from. Defaults to ``None``.
     :type centre_point: Union[np.ndarray, Tuple[float, float, float]], optional
-    :param radius: The radius to extract the subgraph from. Defaults to None.
+    :param radius: The radius to extract the subgraph from. Defaults to ``None``.
     :type radius: float, optional
-    :param ss_elements: List of secondary structure elements to extract. `["H", "B", "E", "G", "I", "T", "S", "-"]` corresponding to Alpha helix
-        Beta bridge, Strand, Helix-3, Helix-5, Turn, Bend, None. Defaults to None.
+    :param ss_elements: List of secondary structure elements to extract. ``["H", "B", "E", "G", "I", "T", "S", "-"]`` corresponding to Alpha helix
+        Beta bridge, Strand, Helix-3, Helix-5, Turn, Bend, None. Defaults to ``None``.
     :type ss_elements: List[str], optional
-    :param rsa_threshold: The threshold to use for the RSA. Defaults to None.
+    :param rsa_threshold: The threshold to use for the RSA. Defaults to ``None``.
     :type rsa_threshold: float, optional
-    :param central_node: The central node to extract the subgraph from. Defaults to None.
+    :param central_node: The central node to extract the subgraph from. Defaults to ``None``.
     :type central_node: str, optional
     :param k: The number of hops to extract.
     :type k: int
-    :param k_only: Whether to only extract the exact k-hop subgraph (e.g. include 2-hop neighbours in 5-hop graph). Defaults to False.
+    :param k_only: Whether to only extract the exact k-hop subgraph (e.g. include 2-hop neighbours in 5-hop graph). Defaults to ``False``.
     :type k_only: bool
-    :param filter_dataframe: Whether to filter the pdb_df dataframe of the graph. Defaults to True. Defaults to None.
+    :param filter_dataframe: Whether to filter the ``pdb_df`` dataframe of the graph. Defaults to ``True``. Defaults to ``None``.
     :type filter_dataframe: bool, optional
-    :param update_coords: Whether to update the coordinates of the graph. Defaults to True.
+    :param update_coords: Whether to update the coordinates of the graph. Defaults to ``True``.
     :type update_coords: bool
-    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to False.
+    :param recompute_distmat: Whether to recompute the distance matrix of the graph. Defaults to ``False``.
     :type recompute_distmat: bool
-    :param inverse: Whether to inverse the selection. Defaults to False.
+    :param inverse: Whether to inverse the selection. Defaults to ``False``.
     :type inverse: bool, optional
-    :return: The subgraph or node list if return_node_list is True.
+    :return: The subgraph or node list if ``return_node_list=True``.
     :rtype: Union[nx.Graph, List[str]]
     """
     if node_list is None:
